import { Ref } from 'vue'
import _ from 'lodash'
import type { TableColumn, TableColumnInGroup } from '../type'

export default function useTableFilter(
  tableColumns: Ref<TableColumnInGroup[] | TableColumn[]>,
  tableData: Ref<any[]>
) {
  watch([tableColumns, tableData], ([columns, records]) => {
    const tempSets = {}
    columns.forEach(column => {
      if (column.needFilters) {
        tempSets[column.columnName] = new Set()
      }
    })
    records.forEach(item => {
      Object.keys(tempSets).forEach(key => {
        '' !== (item[key] ?? '') && tempSets[key].add(String(item[key]))
      })
    })
    Object.keys(tempSets).forEach(key => {
      filterOptionMap[key] = _.orderBy(
        [...tempSets[key]].map(value => ({
          text: value,
          value,
        })),
        o => o.value
      )
    })
  })

  const filterOptionMap = {}
  const filterValueMap = {}
  const tableDataSortRuleMap = {}

  return {
    filterOptionMap,
    filterValueMap,
    tableDataSortRuleMap,
  }
}
